@@ -24,9 +24,11 @@ def PlotBoxWhiskerByGroup(dataframe,
                           subtitle_y_indent=1.05,
                           caption_y_indent=-0.15,
                           x_indent=-0.10,
-                          figure_size=(8, 6)):
+                          figure_size=(8, 6),
+                          # Plot saving arguments
+                          filepath_to_save_plot=None):
     """
-    Function to create a box and whisker plot for a given outcome variable, grouped by one or two categorical variables. 
+    Create a box and whisker plot for a given outcome variable, grouped by one or two categorical variables.
 
     Args:
         dataframe (pandas.DataFrame): The input dataframe.
@@ -36,6 +38,7 @@ def PlotBoxWhiskerByGroup(dataframe,
         fill_color (str, optional): The color to fill the box plot with. Defaults to None.
         color_palette (str, optional): The color palette to use for the box plot. Defaults to 'Set2'.
         display_order_list (list, optional): The order to display the 1st categories in the plot. Defaults to None.
+        show_legend (bool, optional): Whether to show the legend. Defaults to True.
         title_for_plot (str, optional): The title for the plot. Defaults to None.
         subtitle_for_plot (str, optional): The subtitle for the plot. Defaults to None.
         caption_for_plot (str, optional): The caption for the plot. Defaults to None.
@@ -46,7 +49,9 @@ def PlotBoxWhiskerByGroup(dataframe,
         caption_y_indent (float, optional): The y-indent for the caption. Defaults to -0.15.
         x_indent (float, optional): The x-indent for the plot. Defaults to -0.128.
         figure_size (tuple, optional): The size of the plot. Defaults to (8, 6).
+        filepath_to_save_plot (str, optional): The filepath to save the plot. Defaults to None.
     """
+    
     # If display_order_list is provided, check that it contains all of the categories in the dataframe
     if display_order_list != None:
         if not set(display_order_list).issubset(set(dataframe[grouping_column_name_1].unique())):
@@ -186,6 +191,17 @@ def PlotBoxWhiskerByGroup(dataframe,
             color="#666666",
             transform=ax.transAxes
         )
+    # If filepath_to_save_plot is provided, save the plot
+    if filepath_to_save_plot != None:
+        # Ensure that the filepath ends with '.png' or '.jpg'
+        if not filepath_to_save_plot.endswith('.png') and not filepath_to_save_plot.endswith('.jpg'):
+            raise ValueError("The filepath to save the plot must end with '.png' or '.jpg'.")
+        
+        # Save plot
+        plt.savefig(
+            filepath_to_save_plot, 
+            bbox_inches="tight"
+        )
     
     # Show plot
     plt.show()
