@@ -17,6 +17,7 @@ def PlotClusteredBarChart(dataframe,
                           display_order_list=None,
                           figure_size=(6, 6),
                           show_legend=True,
+                          decimal_places_for_data_label=0,
                           # Text formatting arguments
                           title_for_plot=None,
                           subtitle_for_plot=None,
@@ -26,10 +27,10 @@ def PlotClusteredBarChart(dataframe,
                           title_y_indent=1.15,
                           subtitle_y_indent=1.1,
                           caption_y_indent=-0.15,
-                          decimal_places_for_data_label=0):
+                          # Plot saving arguments
+                          filepath_to_save_plot=None):
     """
-    This function creates a clustered bar chart using seaborn. 
-    It takes a pandas DataFrame and column names for grouping and value, along with various optional parameters for plot formatting and text formatting. 
+    Creates a clustered bar chart using seaborn.
 
     Args:
         dataframe (pd.DataFrame): The data to plot.
@@ -40,6 +41,8 @@ def PlotClusteredBarChart(dataframe,
         fill_transparency (float, optional): The transparency of the bars. Defaults to 0.8.
         display_order_list (list, optional): The order to display the 1st categories in the plot. Defaults to None.
         figure_size (tuple, optional): The size of the figure. Defaults to (6, 6).
+        show_legend (bool, optional): Whether to show the legend. Defaults to True.
+        decimal_places_for_data_label (int, optional): The number of decimal places for the data labels. Defaults to 0.
         title_for_plot (str, optional): The title for the plot. Defaults to None.
         subtitle_for_plot (str, optional): The subtitle for the plot. Defaults to None.
         caption_for_plot (str, optional): The caption for the plot. Defaults to None.
@@ -48,8 +51,9 @@ def PlotClusteredBarChart(dataframe,
         title_y_indent (float, optional): The y-indent for the title. Defaults to 1.15.
         subtitle_y_indent (float, optional): The y-indent for the subtitle. Defaults to 1.1.
         caption_y_indent (float, optional): The y-indent for the caption. Defaults to -0.15.
-        decimal_places_for_data_label (int, optional): The number of decimal places for the data labels. Defaults to 0.
+        filepath_to_save_plot (str, optional): The filepath to save the plot. Defaults to None.
     """
+    
     # If display_order_list is provided, check that it contains all of the categories in the dataframe
     if display_order_list != None:
         if not set(display_order_list).issubset(set(dataframe[grouping_column_name_1].unique())):
@@ -178,6 +182,18 @@ def PlotClusteredBarChart(dataframe,
             transform=ax.ax.transAxes
         )
     
+    # If filepath_to_save_plot is provided, save the plot
+    if filepath_to_save_plot != None:
+        # Ensure that the filepath ends with '.png' or '.jpg'
+        if not filepath_to_save_plot.endswith('.png') and not filepath_to_save_plot.endswith('.jpg'):
+            raise ValueError("The filepath to save the plot must end with '.png' or '.jpg'.")
+        
+        # Save plot
+        plt.savefig(
+            filepath_to_save_plot, 
+            bbox_inches="tight"
+        )
+    
     # Show plot
     plt.show()
     
