@@ -11,6 +11,7 @@ def PlotDensityByGroup(dataframe,
                        # Plot formatting arguments
                        color_palette='Set2',
                        show_legend=True,
+                       figure_size=(8, 6),
                        # Text formatting arguments
                        title_for_plot=None,
                        subtitle_for_plot=None,
@@ -20,17 +21,18 @@ def PlotDensityByGroup(dataframe,
                        title_y_indent=1.1,
                        subtitle_y_indent=1.05,
                        caption_y_indent=-0.15,
-                       # Plot formatting arguments
-                       figure_size=(8, 6)):
+                       # Plot saving arguments
+                       filepath_to_save_plot=None):
     """
-    This function generates a density plot for a given dataframe, with the option to group by a specific column.
-    The plot is generated using seaborn's kdeplot function.
+    Generates a density plot for a given dataframe, with the option to group by a specific column.
 
     Args:
         dataframe (pandas.DataFrame): The dataframe to plot.
         value_column_name (str): The name of the column in the dataframe to use for the x-axis values.
         grouping_column_name (str): The name of the column in the dataframe to use for grouping data.
         color_palette (str, optional): The color palette to use for the plot. Defaults to 'Set2'.
+        show_legend (bool, optional): Whether to show the legend. Defaults to True.
+        figure_size (tuple, optional): The size of the figure. Defaults to (8, 6).
         title_for_plot (str, optional): The title for the plot. Defaults to None.
         subtitle_for_plot (str, optional): The subtitle for the plot. Defaults to None.
         caption_for_plot (str, optional): The caption for the plot. Defaults to None.
@@ -39,7 +41,7 @@ def PlotDensityByGroup(dataframe,
         title_y_indent (float, optional): The y-indent for the title. Defaults to 1.1.
         subtitle_y_indent (float, optional): The y-indent for the subtitle. Defaults to 1.05.
         caption_y_indent (float, optional): The y-indent for the caption. Defaults to -0.15.
-        figure_size (tuple, optional): The size of the figure. Defaults to (8, 6).
+        filepath_to_save_plot (str, optional): The filepath to save the plot. Defaults to None.
     """
     
     # Create figure and axes
@@ -132,6 +134,18 @@ def PlotDensityByGroup(dataframe,
             color="#666666",
             transform=ax.transAxes
         )
+    
+    # If filepath_to_save_plot is provided, save the plot
+    if filepath_to_save_plot != None:
+        # Ensure that the filepath ends with '.png' or '.jpg'
+        if not filepath_to_save_plot.endswith('.png') and not filepath_to_save_plot.endswith('.jpg'):
+            raise ValueError("The filepath to save the plot must end with '.png' or '.jpg'.")
+        
+        # Save plot
+        plt.savefig(
+            filepath_to_save_plot, 
+            bbox_inches="tight"
+        )
         
     # Show plot
     plt.show()
