@@ -29,9 +29,11 @@ def PlotTimeSeries(dataframe,
                    subtitle_y_indent=1.05,
                    caption_y_indent=-0.3,
                    # Plot formatting arguments
-                   figure_size=(8, 5)):
+                   figure_size=(8, 5),
+                   # Plot saving arguments
+                   filepath_to_save_plot=None):
     """
-    This function plots a time series from a given dataframe.
+    Plots a time series from a given dataframe.
 
     Args:
         dataframe (pandas.DataFrame): The dataframe containing the data to be plotted.
@@ -54,6 +56,7 @@ def PlotTimeSeries(dataframe,
         subtitle_y_indent (float, optional): The y-indent for the plot subtitle. Defaults to 1.05.
         caption_y_indent (float, optional): The y-indent for the plot caption. Defaults to -0.3.
         figure_size (tuple, optional): The size of the figure for the plot. Defaults to (8, 5).
+        filepath_to_save_plot (str, optional): The filepath to save the plot. Defaults to None.
     """
     
     # Create figure and axes
@@ -204,7 +207,22 @@ def PlotTimeSeries(dataframe,
             color="#666666",
             transform=ax.transAxes
         )
-
+    
+    # If filepath_to_save_plot is provided, save the plot
+    if filepath_to_save_plot != None:
+        # Ensure that the filepath ends with '.png' or '.jpg'
+        if not filepath_to_save_plot.endswith('.png') and not filepath_to_save_plot.endswith('.jpg'):
+            raise ValueError("The filepath to save the plot must end with '.png' or '.jpg'.")
+        
+        # Save plot
+        plt.savefig(
+            filepath_to_save_plot,
+            bbox_inches="tight"
+        )
+    
     # Show plot
     plt.show()
+        
+    # Clear plot
+    plt.clf()
     
